@@ -11,6 +11,9 @@ try:
 except ImportError:
     import urllib.parse as urlparse
 
+if sys.version_info >= (3, 0, 0):
+    basestring = str
+
 
 class Headers(object):
     def __init__(self, res):
@@ -80,6 +83,7 @@ class HTTMock(object):
     Acts as a context manager to allow mocking
     """
     STATUS_CODE = 200
+
     def __init__(self, *handlers):
         self.handlers = handlers
 
@@ -108,9 +112,13 @@ class HTTMock(object):
                             res.get('reason'),
                             res.get('elapsed', 0),
                             request)
-        obj = requests.Response()
-        obj._content = res
-        return obj
+        elif isinstance(res, basestring):
+            return response(content=res)
+        elif res is None:
+            return None
+        else:
+            raise TypeError(
+                "Dont know how to handle response of type {}".format(type(res)))
 
 
 def with_httmock(*handlers):
